<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AlertDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BackupWidget</name>
    <message>
        <source>Backing up…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backing up the current system, please wait patiently</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BorderRadiusHeaderView</name>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CheckImageResultWidget</name>
    <message>
        <source>File size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ISO version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The image file is ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some applications may not work properly after the upgrade.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The version or integrity of the image file does not meet requirements.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CheckImageWidget</name>
    <message>
        <source>Verifying the integrity…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CheckSizeThread</name>
    <message>
        <source>Unable to get the image file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConditionChecklistWidget</name>
    <message>
        <source>System version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The system version is too old, and the upgrade may fail. To upgrade successfully, please update your system to the latest version in the Control Center first (you can ignore it and force an upgrade as well).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requirement: deepin (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requirement: Professional (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authorization status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requirement: Activated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CPU architecture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requirement: X86</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Storage space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are risks, but you can force an upgrade.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Professional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too old</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unactivated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requirement: %1 GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data disk %1 GB / %2 GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System disk %1 GB / %2 GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DBusWorker</name>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upgrade failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restoration failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDownloader</name>
    <message>
        <source>URL &quot;%1&quot; is illegal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageDownloadWidget</name>
    <message>
        <source>Downloading the V23 image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can continue using the computer without being affected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time remaining: %1 / File size: %2 GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePreparationWidget</name>
    <message>
        <source>Download failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to exit the downloading?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to exit the image file checking?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reselect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to connect to the server. Please check your network connection or select a local V23 image file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your computer is not plugged in, please plug in a power cord first and then upgrade.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Upgrade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to exit software evaluation?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software evaluation failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InitialWidget</name>
    <message>
        <source>Current version: V%1</source>
        <translation></translation>
    </message>
    <message>
        <source>Take a few simple steps to upgrade your system to</source>
        <translation></translation>
    </message>
    <message>
        <source>Pre-Check</source>
        <translation></translation>
    </message>
    <message>
        <source>End User License Agreement for Deepin Upgrade Tool</source>
        <translation></translation>
    </message>
    <message>
        <source>:/text/end_user_license_en.txt</source>
        <translation></translation>
    </message>
    <message>
        <source>Privacy Protection Guide for Deepin Upgrade Tool</source>
        <translation></translation>
    </message>
    <message>
        <source>:/text/privacy_protection_guide_en.txt</source>
        <translation></translation>
    </message>
    <message>
        <source>Disagree</source>
        <translation></translation>
    </message>
    <message>
        <source>Agree</source>
        <translation></translation>
    </message>
    <message>
        <source>&quot;End User License Agreement for Deepin Upgrade Tool&quot;</source>
        <translatorcomment>Titile for the checkbox text.</translatorcomment>
        <translation>End User License Agreement</translation>
    </message>
    <message>
        <source>&quot;Privacy Protection Guide&quot;</source>
        <translatorcomment>Titile for the checkbox text.</translatorcomment>
        <translation>Privacy Protection Guide</translation>
    </message>
    <message>
        <source>I have read and agreed to the &lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt; and &lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;.</source>
        <translation></translation>
    </message>
    <message>
        <source>System Upgrade Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deepin 23</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Do you want to exit the Deepin Upgrade Tool?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upgrade failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MigrateFinishedWidget</name>
    <message>
        <source>App migration successful</source>
        <translation></translation>
    </message>
    <message>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MigrateProgressWidget</name>
    <message>
        <source>Migrating apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Migrating apps, please wait patiently</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network error. App migration has been interrupted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network connection failed. Please check your network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MigrateWidget</name>
    <message>
        <source>App migration failed</source>
        <translation></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation></translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProgressWidget</name>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time remaining: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RestorationWidget</name>
    <message>
        <source>Restoring…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upgrade failed. Your system is being restored to the previous version.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RetrieveImageMethodWidget</name>
    <message>
        <source>Get Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download from Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import local image files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format: ISO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drag files here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoftwareCheckProgressWidget</name>
    <message>
        <source>Software Evaluation</source>
        <translation></translation>
    </message>
    <message>
        <source>Evaluate the compatibility of installed apps in the new system</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SoftwareEvaluationOfflineWidget</name>
    <message>
        <source>Software Evaluation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your current usage scenario is in a state of no network. We cannot evaluate the software you are using. After the upgrade is complete, the software you are currently installing needs to be reinstalled. If you want to view the details of the applications that can be installed for the upgrade, please upgrade online</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoftwareEvaluationWidget</name>
    <message>
        <source>Evaluation Result</source>
        <translation></translation>
    </message>
    <message>
        <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
        <translation></translation>
    </message>
    <message>
        <source>The system upgrade will ensure the integrity of user data, and we will not delete user data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The cross-version upgrade does not migrate the application. After the upgrade is completed, it supports automatic installation of the selected compatible application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compatible Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incompatible Apps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StorageResultWidget</name>
    <message>
        <source>Free up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your system cannot be upgraded to V23</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clean system disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 GB free space required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clean data disk</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemUpgradeWidget</name>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restoration failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After clicking restart, the system will be upgraded, please save the current running application data before confirming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpgradeCheckProgressWidget</name>
    <message>
        <source>Pre-Check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check your computer to see if it meets the upgrade conditions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpgradeCheckResultWidget</name>
    <message>
        <source>Passed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpgradeCheckWidget</name>
    <message>
        <source>Do you want to exit the pre-upgrade checking?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpgradeWidget</name>
    <message>
        <source>Upgrading…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preparing for system upgrade, please wait patiently</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Deepin Upgrade Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deepin Upgrade Tool helps you upgrade the system to version 23.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upgrade successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Successfully upgraded to version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error code: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
